==> patch-3.9.1-ONex-OMS-third-source-PHP5.6.tar.gz: ShopexErp/app/ome/lib/shop/type.php <==
<?php
class ome_shop_type{

    /**
     * 节点类型
     * @access public
     * @return Array
     */
    static function get_shop_type(){
        $shop_type = array (
            'shopex_b2c' => '48体系网店',
            'shopex_b2b' => '分销王',
            'ecos.ome' => '后端业务处理系统',
            'ecos.b2c' => 'ec-store',
            'ecos.dzg' => '直销平台',
            'taobao' => '淘宝',
            'paipai' => '拍拍',
            '360buy' => '京东',
            'ecshop_b2c' => 'ecshop',
            'yihaodian' => '一号店',
            'qq_buy' => 'qq网购',
            'dangdang' => '当当',
            'amazon' => '亚马逊',
            'yintai' => '银泰',
            'vjia' => '凡客',
            'alibaba' => '阿里巴巴',
            'suning' => '苏宁',
            'wx' => '微信',
            'gome' => '国美',
            'mogujie' => '蘑菇街',
            'icbc'=>'工行',
            'ccb'=>'建行',
            'meilishuo'=>'美丽说',
            'feiniu'=>'飞牛',
            'youzan'=>'有赞',
            'juanpi'=>'卷皮' ,
            'mia'=>'蜜芽宝贝' ,
            'bbc'=>'bbc商城',
            'beibei'=>'贝贝网',
            'vop'=>'唯品会',
            'wdwd'=>'有量',
            'mengdian'=> '萌店',
            'zhe800' => '折800',
            'weimeng'=> '微盟',
            'mls'=>'美丽说2',
            'mgj'=>'蘑菇街2',
            'kaola'=>'网易考拉',
            'pinduoduo'=>'拼多多',            
            'shopex_fy'=>'全民分销',
            'public_b2c' => '独立B2C',          
        );
        return $shop_type;
    }

    /**
     * 获取节点类型名称
     * @param string $shop_type 店铺类型
     * @return 店铺类型名称
     */
    static function shop_name($shop_type=''){
        $types = self::get_shop_type();
        return $types[$shop_type];
    }

    /**
     * C2C前端店铺列表
     * @return array
     */
    static function shop_list(){
        $shop = array('taobao','paipai','youa','360buy','yihaodian','qq_buy','dangdang','amazon','yintai','vjia','alibaba','suning','icbc','mogujie','gome','wx','ccb','meilishuo','feiniu','youzan','juanpi','mia','beibei','vop','wdwd','mengdian','zhe800','weimeng','mls','mgj', 'kaola', 'pinduoduo');
        return $shop;
    }

    /**
     * B2B前端店铺列表
     * @return array
     */
    static function b2b_shop_list(){
        $shop = array('shopex_b2b');
        return $shop;
    }
    /**
     * 库存回写是否增加本店铺冻结库存
     * @access public
     * @return Array
     */
    static function get_store_config(){
        $store_config = array (
            'shopex_b2b' => 'off',
            'shopex_b2c' => 'off',
            'ecos.b2c' => 'off',
            'ecos.dzg' => 'off',
            'ecshop_b2c' => 'off',
            'taobao' => 'off',
            'paipai' => 'off',
            'qq_buy' => 'off',
            '360buy' => 'on',
            'yihaodian' => 'on',
            'dangdang' => 'off',
            'amazon' => 'off',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'off',
            'suning' => 'off',
            'beibei' => 'off',
            'vop' => 'off',
            'wdwd' => 'off',
            'mengdian'=>'off',
            'zhe800'=>'off',
            'weimeng'=>'off',
        );
        return $store_config;
    }

    /**
     * 京东类型
     * 京东类型
     * @return array
     */
    static function jingdong_type(){
        $shop = array('360buy');
        return $shop;
    }

    /**
     * shopex前端店铺列表
     * @author yangminsheng
     * @return array
     **/
    static function shopex_shop_type(){
        $shop = array('shopex_b2b','shopex_b2c','ecos.b2c','ecshop_b2c','ecos.dzg','bbc');
        return $shop;
    }

    /**
     * (已弃用) chenping 2014-1-9
     * 前端店铺是否需要发货明细
     * @params on 需要发货明细 off 不需要
     * @return void
     * @author
     **/
    static function is_shop_deliveryitem($shop_type = null)
    {
        $shop_list = array(
            'shopex_b2c' => 'on',
            'shopex_b2b' => 'on',
            'ecos.b2c' => 'on',
            'ecos.dzg' => 'on',
            'taobao' => 'off',
            'paipai' => 'off',
            '360buy' => 'off',
            'ecshop_b2c' => 'off',
            'yihaodian' => 'off',
            'qq_buy' => 'off',
            'dangdang' => 'on',
            'amazon' => 'on',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'off',
        );

        return $shop_list[$shop_type];
    }

    /**
     * 是否允许开启单独获取店铺订单配置
     * @param shop_type
     * @return void
     * @author
     **/
    static function get_shoporder_config($shop_type = null)
    {
        $shop_config = array(
            'shopex_b2b' => 'on',
            'shopex_b2c' => 'on',
            'ecos.b2c' => 'on',
            'ecos.dzg' => 'on',
            'taobao' => 'on',
            'paipai' => 'on',
            'qq_buy' => 'on',
            '360buy' => 'on',
            'yihaodian' => 'on',
            'dangdang' => 'off',
            'amazon' => 'off',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'on',
            'suning' => 'on',
            'icbc' => 'on',
            'beibei' => 'on',
            'wdwd' => 'on',
            'vop' => 'off',
            'youzan' => 'on',
            'meilishuo' => 'on',
            'mls' => 'on',
            'ccb' => 'on',
            'mia' => 'on',
            'feiniu' => 'on',
            'gome' => 'on',
            'juanpi' => 'on',
            'mogujie' => 'on',
            'wx' => 'on',
            'ecshop_b2c' => 'on',
            'bbc' => 'on',
            'mengdian' => 'on',
            'zhe800' => 'on',
            'weimeng'=>'on',
            'mls' => 'on',
            'mgj' => 'on',
            'kaola'=>'on',
            'pinduoduo'=>'on',
        );

        if(!empty($shop_type)){
            return $shop_config[$shop_type];
        }

        return $shop_config;
    }

}

==> patch-4.1.3-ONex-OMS-third-source-PHP5.6.tar.gz: ShopexErp/app/ome/lib/shop/type.php <==
<?php
class ome_shop_type{

    /**
     * 节点类型
     * @access public
     * @return Array
     */
    static function get_shop_type(){
        $shop_type = array (
            'shopex_b2c' => '48体系网店',
            'shopex_b2b' => '分销王',
            //'ecos.ome' => '后端业务处理系统',
            'ecos.b2c' => 'ECSTORE',
            'ecos.dzg' => '直销平台',
            'taobao' => '淘宝',
            'paipai' => '拍拍',
            '360buy' => '京东',
            'ecshop_b2c' => 'ECSHOP',
            'yihaodian' => '一号店',
            'qq_buy' => 'QQ网购',
            'dangdang' => '当当',
            'amazon' => '亚马逊',
            'yintai' => '银泰',
            'vjia' => '凡客',
            'alibaba' => '阿里巴巴',
            'suning' => '苏宁',
            'wx' => '微信',
            'gome' => '国美',
            'mogujie' => '蘑菇街',
            'icbc'=>'工行',
            'ccb'=>'建行',
            'meilishuo'=>'美丽说',
            'feiniu'=>'飞牛',
            'youzan'=>'有赞',
            'juanpi'=>'卷皮' ,
            'mia'=>'蜜芽宝贝' ,
            'bbc'=>'BBC商城',
            'beibei'=>'贝贝网',
            'vop'=>'唯品会',
            'wdwd'=>'有量',
            'mengdian'=> '萌店',
            'zhe800' => '折800',
            'weimob'=> '微盟旺铺',
            'mls'=>'新美丽说',
            'mgj'=>'新蘑菇街',
            'kaola'=>'网易考拉',
	        'shopex_fy'=>'全民分销',
            'public_b2c' => '独立B2C',
            'pinduoduo'=>'拼多多',
            'shopex_penkrwd'=>'朋客',
            'ecos.b2b2c.stdsrc'=>'新BBC商城',
            'cmb'   => '招商银行',
          );
        return $shop_type;
    }

    /**
     * 获取节点类型名称
     * @param string $shop_type 店铺类型
     * @return 店铺类型名称
     */
    static function shop_name($shop_type=''){
        $types = self::get_shop_type();
        return $types[$shop_type];
    }

    /**
     * C2C前端店铺列表
     * @return array
     */
    static function shop_list(){
        $shop = array('taobao','paipai','youa','360buy','yihaodian','qq_buy','dangdang','amazon','yintai','vjia','alibaba','suning','icbc','mogujie','gome','wx','ccb','meilishuo','feiniu','youzan','juanpi','mia','beibei','vop','wdwd','mengdian','zhe800','weimob','mls','mgj', 'kaola', 'pinduoduo','cmb');
        return $shop;
    }

    /**
     * B2B前端店铺列表
     * @return array
     */
    static function b2b_shop_list(){
        $shop = array('shopex_b2b');
        return $shop;
    }
    /**
     * 库存回写是否增加本店铺冻结库存
     * @access public
     * @return Array
     */
    static function get_store_config(){
        $store_config = array (
            'shopex_b2b' => 'off',
            'shopex_b2c' => 'off',
            'ecos.b2c' => 'off',
            'ecos.dzg' => 'off',
            'ecshop_b2c' => 'off',
            'taobao' => 'off',
            'paipai' => 'off',
            'qq_buy' => 'off',
            '360buy' => 'on',
            'yihaodian' => 'on',
            'dangdang' => 'off',
            'amazon' => 'off',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'off',
            'suning' => 'off',
            'beibei' => 'off',
            'vop' => 'off',
            'wdwd' => 'off',
            'mengdian' => 'off',
            'zhe800'=>'off',
            'weimob'=>'off',

        );
        return $store_config;
    }

    /**
     * 京东类型
     * 京东类型
     * @return array
     */
    static function jingdong_type(){
        $shop = array('360buy');
        return $shop;
    }

    /**
     * shopex前端店铺列表
     * @author yangminsheng
     * @return array
     **/
    static function shopex_shop_type(){
        $shop = array('shopex_b2b','shopex_b2c','ecos.b2c','ecshop_b2c','ecos.dzg','bbc','ecos.b2b2c.stdsrc','shopex_fy','shopex_penkrwd');
        return $shop;
    }

    /**
     * (已弃用) chenping 2014-1-9
     * 前端店铺是否需要发货明细
     * @params on 需要发货明细 off 不需要
     * @return void
     * @author
     **/
    static function is_shop_deliveryitem($shop_type = null)
    {
        $shop_list = array(
            'shopex_b2c' => 'on',
            'shopex_b2b' => 'on',
            'ecos.b2c' => 'on',
            'ecos.dzg' => 'on',
            'taobao' => 'off',
            'paipai' => 'off',
            '360buy' => 'off',
            'ecshop_b2c' => 'off',
            'yihaodian' => 'off',
            'qq_buy' => 'off',
            'dangdang' => 'on',
            'amazon' => 'on',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'off',
        );

        return $shop_list[$shop_type];
    }

    /**
     * 是否允许开启单独获取店铺订单配置
     * @param shop_type
     * @return void
     * @author
     **/
    static function get_shoporder_config($shop_type = null)
    {
        $shop_config = array(
            'shopex_b2b' => 'on',
            'shopex_b2c' => 'on',
            'ecos.b2c' => 'on',
            'ecos.dzg' => 'on',
            'taobao' => 'on',
            'paipai' => 'on',
            'qq_buy' => 'on',
            '360buy' => 'on',
            'yihaodian' => 'on',
            'dangdang' => 'off',
            'amazon' => 'off',
            'yintai' => 'off',
            'vjia' => 'off',
            'alibaba' => 'on',
            'suning' => 'on',
            'icbc' => 'on',
            'beibei' => 'on',
            'wdwd' => 'on',
            'vop' => 'off',
            'youzan' => 'on',
            'meilishuo' => 'on',
            'mls' => 'on',
            'ccb' => 'on',
            'mia' => 'on',
            'feiniu' => 'on',
            'gome' => 'on',
            'juanpi' => 'on',
            'mogujie' => 'on',
            'wx' => 'on',
            'ecshop_b2c' => 'on',
            'bbc' => 'on',
            'mengdian' => 'on',
            'zhe800' => 'on',
            'weimob'=>'on',
            'mls' => 'on',
            'mgj' => 'on',
            'kaola'=>'on',
            'pinduoduo'=>'on',
            'ecos.b2b2c.stdsrc'=> 'on',
        );

        if(!empty($shop_type)){
            return $shop_config[$shop_type];
        }

        return $shop_config;
    }

    /**
     * 采购单同步店铺
     */
    static function get_shop_purchase_sync($shop_type = null)
    {
        $shop_list = array('vop'=>'on');
        
        return ($shop_list[$shop_type]=='on' ? true : false);
    }
}
